==> haskell-text-format-0.3.2.1-134.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-format
version:              0.3.2.1
visibility:           public
id:                   text-format-0.3.2.1-Lc2KOseRxhNkoeyO8mKBz
key:                  text-format-0.3.2.1-Lc2KOseRxhNkoeyO8mKBz
license:              BSD-3-Clause
maintainer:           Hackage Trustees
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/hackage-trustees/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  d0f5e4d4da869d1de669df5628ddbe02
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-format
hs-libraries:         HStext-format-0.3.2.1-Lc2KOseRxhNkoeyO8mKBz
depends:
    array-0.5.6.0 base-4.18.2.1
    double-conversion-2.0.5.0-7k3PQbk5wVvDnUdJiFaADT ghc-prim-0.10.0
    integer-gmp-1.1 old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    text-2.0.2 time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-format-0.3.2.1-135-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-format
version:              0.3.2.1
visibility:           public
id:                   text-format-0.3.2.1-J5i0JObvqjMCYQKVw5dj5Q
key:                  text-format-0.3.2.1-J5i0JObvqjMCYQKVw5dj5Q
license:              BSD-3-Clause
maintainer:           Hackage Trustees
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/hackage-trustees/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  ed1a4877685c166bd42c7d161f1fcb1e
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-format-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-format
hs-libraries:         HStext-format-0.3.2.1-J5i0JObvqjMCYQKVw5dj5Q
depends:
    array-0.5.6.0 base-4.18.2.1
    double-conversion-2.0.5.0-CdOSsqedBsNJWYHDnXIs1L ghc-prim-0.10.0
    integer-gmp-1.1 old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    text-2.0.2 time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
